[![Build Status](https://img.shields.io/travis/robpogorzelski/django-permissionsx/develop.svg)](https://travis-ci.org/robpogorzelski/django-permissionsx)
[![Coverage Status](https://img.shields.io/codecov/c/github/robpogorzelski/django-permissionsx/develop.svg)](https://codecov.io/gh/robpogorzelski/django-permissionsx)
[![Latest Version](https://img.shields.io/pypi/v/django-permissionsx.svg)](https://pypi.python.org/pypi/django-permissionsx/)
[![Python Versions](https://img.shields.io/pypi/pyversions/django-permissionsx.svg)](https://pypi.python.org/pypi/django-permissionsx/)
[![License](https://img.shields.io/badge/license-BSD-blue.svg)](https://pypi.python.org/pypi/django-permissionsx/)
[![Documentation Status](https://readthedocs.org/projects/django-permissionsx/badge/?version=latest)](http://django-permissionsx.readthedocs.io/en/latest/?badge=latest)

# django-permissionsx

* [Changelog](http://django-permissionsx.readthedocs.org/en/develop/changelog.html)
* [Python package](http://pypi.python.org/pypi/django-permissionsx/)
* [Example project](http://github.com/robpogorzelski/django-permissionsx-example)

## Compatibility note

This package in version 2.x is intended to work with Python 3.6+ and Django 1.11+.

## Quick Start

### 1. Install *django-permissionsx* package:

        pip install django-permissionsx

### 2. Don't forget to add *permissionsx* to your *INSTALLED_APPS*:

        INSTALLED_APPS = (
            'django.contrib.admin',
            'django.contrib.auth',
            'django.contrib.staticfiles',
            [...]
            'permissionsx',

### 3. Define permissions in a module of your choice:

        def is_owner(context):
            return context('request.user') == context('view.get_object.user')

        def is_staff(context):
            return context('request.user.is_staff')

        def is_staff_or_owner(context):
            return is_owner(context) or is_staff(context)

### 4. Use permissions in your views, e.g.:

        from permissionsx.contrib.django import views
        from example.profiles.permissions import is_staff_or_owner

        class ObjectDetailView(views.PermissionsDetailView):

            model = Item
            permissions = is_staff_or_owner

### 5. Apply permissions to your templates if you need:

        {% load permissionsx_tags %}

        {% permissions 'example.profiles.permissions.is_staff_or_owner' as is_staff_or_owner %}
        <ul id="utility-navigation">
            {% if is_staff_or_owner %}
                <a href="#">Edit article</a>
            {% endif %}
        </ul>

### 6. If you'd like to display a default message each time a user is denied access, simply:

        from permissionsx.contrib.django import views

        class ObjectDetailView(PermissionsDetailView):

            [...]
            permissions_response_class = views.AccessDeniedView

### 7. You're done!

If a given object has a `ForeignKey` field named `user` that points to the user requesting the
view (`request.user`), the permissions module will either let execute one of the HTTP methods
or simply redirect to the login screen (or log the user out, depends on the configuration).

Browse through `permissionsx.tests.permissions` for more ideas on how to use this package or
check out the [example](http://github.com/robpogorzelski/django-permissionsx-example) for a
good starting point. Also, drop me a line if you have questions (or there is something I could
improve on my side).
