"""PermissionsX - Authorization for Django.

:copyright: Copyright (c) 2013-2017 by Robert Pogorzelski.
:license:   BSD, see LICENSE for more details.

"""


def default_permissions(context):
    return True


class PermissionsCheckMixin:

    def permissions_check(self, data):
        context = Context(data)
        return self.permissions.__func__(context)


class Context:

    def __init__(self, context):
        self.context = context

    def __call__(self, exp):
        return self.dissection(self.context, exp)

    def dissection(self, context, exp):
        attr_name, _, remainder = exp.partition('.')
        try:
            attr = context[attr_name]
        except (AttributeError, TypeError, KeyError):
            try:
                attr = getattr(context, attr_name)
            except AttributeError:
                # NOTE: If attribute is missing assume the permission
                #       is not granted.
                return False
        if callable(attr):
            result = attr()
        else:
            result = attr
        if remainder:
            return self.dissection(result, remainder)
        else:
            return result
