"""PermissionsX - Authorization for Django.

:copyright: Copyright (c) 2013-2017 by Robert Pogorzelski.
:license:   BSD, see LICENSE for more details.

"""
from django import template

from permissionsx import base
from permissionsx import utils


register = template.Library()


@register.assignment_tag(takes_context=True)
def permissions(context, permissions_path):
    """Template tag for checking permissions inside templates.

    Usage:
    ::

        {% load permissionsx_tags %}
        {% permissions 'example.profiles.permissions.is_author' as is_author %}

    """
    perm_context = {'request': context['request']}
    if 'view' in context:
        perm_context.update({'view': context['view']})
    module, _, name = permissions_path.rpartition('.')
    permissions = utils.get_obj(module, name)
    return permissions(base.Context(perm_context))
