"""PermissionsX - Authorization for Django.

:copyright: Copyright (c) 2013-2017 by Robert Pogorzelski.
:license:   BSD, see LICENSE for more details.

"""
from tastypie.authorization import Authorization
from tastypie.exceptions import Unauthorized

from permissionsx import base


class TastypieAuthorization(base.PermissionsCheckMixin, Authorization):
    """Inherits from :class:`tastypie.authorization.Authorization` and
    :class:`permissionsx.base.PermissionsCheckMixin`.

    Usage:
    ::
        from permissionsx.contrib.django import tastypie
        from myproject.myapp import permissions

        class StaffOnlyAuthorization(tastypie.TastypieAuthorization):

            permissions = permissions.is_staff

    """
    def read_list(self, object_list, bundle):
        if self.permissions_check({'request': bundle.request}):
            return object_list
        raise Unauthorized()

    def read_detail(self, object_list, bundle):
        return self.permissions_check({'request': bundle.request})

    def create_list(self, object_list, bundle):
        if self.permissions_check({'request': bundle.request}):
            return object_list
        raise Unauthorized()

    def create_detail(self, object_list, bundle):
        return self.permissions_check({'request': bundle.request})

    def update_list(self, object_list, bundle):
        if self.permissions_check({'request': bundle.request}):
            return object_list
        raise Unauthorized()

    def update_detail(self, object_list, bundle):
        return self.permissions_check({'request': bundle.request})

    def delete_list(self, object_list, bundle):
        return self.permissions_check({'request': bundle.request})

    def delete_detail(self, object_list, bundle):
        return self.permissions_check({'request': bundle.request})
