"""PermissionsX - Authorization for Django.

:copyright: Copyright (c) 2013-2017 by Robert Pogorzelski.
:license:   BSD, see LICENSE for more details.

"""
from django.conf.urls import (
    include,
    url,
)

import debug_toolbar
from tastypie.api import Api
from tastypie.resources import ModelResource
from tastypie.serializers import Serializer
from tastypie.exceptions import Unauthorized

from permissionsx.contrib.tastypie import TastypieAuthorization
from permissionsx.tests.models import TestObject
from permissionsx.tests import (
    permissions,
    views,
)


class SuperuserOnlyAuthorization(TastypieAuthorization):

    permissions = permissions.is_superuser


class UpdatingOnlyAuthorization(TastypieAuthorization):

    permissions = permissions.is_authenticated

    def create_list(self, object_list, bundle):
        raise Unauthorized()

    def update_list(self, object_list, bundle):
        raise Unauthorized()

    def update_detail(self, object_list, bundle):
        return self.permissions_check({'request': bundle.request})

    def delete_list(self, object_list, bundle):
        raise Unauthorized()

    def delete_detail(self, object_list, bundle):
        raise Unauthorized()


class TestSuperuserResource(ModelResource):

    class Meta:
        authorization = SuperuserOnlyAuthorization()
        queryset = TestObject.objects.all()
        fields = ('id', 'title')
        serializer = Serializer()


class TestOverrideResource(ModelResource):

    class Meta:
        authorization = UpdatingOnlyAuthorization()
        queryset = TestObject.objects.all()
        fields = ('id', 'title')
        serializer = Serializer()


v1_api = Api(api_name='v1')
v1_api.register(TestSuperuserResource())
v1_api.register(TestOverrideResource())


urlpatterns = [
    url(r'^accounts/login/$', views.LoginView.as_view(), name='login'),
    url(r'^accounts/login2/$', views.Login2View.as_view(), name='login2'),
    url(r'^authenticated/$', views.AuthenticatedView.as_view(), name='authenticated'),
    url(r'^response-class/$', views.ResponseClassView.as_view(), name='response_class'),
    url(r'^superuser/$', views.SuperuserView.as_view(), name='superuser'),
    url(r'^menu/$', views.MenuView.as_view(), name='menu'),
    url(r'^api/', include(v1_api.urls)),
    url(r'^__debug__/', include(debug_toolbar.urls)),
]
